@@ -429,11 +429,7 @@ impl Build {
         }
 
         let draw_target = ProgressTarget::Stdout;
-        let ctx = if self.xwin_cache_dir.is_some() {
-            xwin::Ctx::with_dir(cache_dir.clone().try_into()?, draw_target)?
-        } else {
-            xwin::Ctx::with_temp(draw_target)?
-        };
+        let ctx = xwin::Ctx::with_dir(cache_dir.clone().try_into()?, draw_target)?;
         let ctx = std::sync::Arc::new(ctx);
         let pkg_manifest = self.load_manifest(&ctx, draw_target)?;
 
